@@ -216,7 +216,7 @@ def collapse_message(message, maxCharsPerLine, maxLines):
 
 
 def _get_contact_numbers(backend, contactId, number):
-	if contactId:
+	if contactId and contactId != '0':
 		contactPhoneNumbers = list(backend.get_contact_details(contactId))
 		uglyContactNumbers = (
 			make_ugly(contactNumber)
@@ -676,6 +676,14 @@ class Dialpad(object):
 		"""
 		pass
 
+	def set_orientation(self, orientation):
+		if orientation == gtk.ORIENTATION_VERTICAL:
+			pass
+		elif orientation == gtk.ORIENTATION_HORIZONTAL:
+			pass
+		else:
+			raise NotImplementedError(orientation)
+
 	def _on_key_press(self, widget, event):
 		try:
 			if event.keyval == ord("v") and event.get_state() & gtk.gdk.CONTROL_MASK:
@@ -872,6 +880,14 @@ class AccountInfo(object):
 		config.set(section, "notifyOnVoicemail", repr(self._notifyOnVoicemail))
 		config.set(section, "notifyOnSms", repr(self._notifyOnSms))
 
+	def set_orientation(self, orientation):
+		if orientation == gtk.ORIENTATION_VERTICAL:
+			pass
+		elif orientation == gtk.ORIENTATION_HORIZONTAL:
+			pass
+		else:
+			raise NotImplementedError(orientation)
+
 	def _populate_callback_combo(self):
 		self._isPopulated = True
 		del self._callbackList[:]
@@ -1168,6 +1184,14 @@ class CallHistoryView(object):
 		"""
 		config.set(sectionName, "filter", self._selectedFilter)
 
+	def set_orientation(self, orientation):
+		if orientation == gtk.ORIENTATION_VERTICAL:
+			pass
+		elif orientation == gtk.ORIENTATION_HORIZONTAL:
+			pass
+		else:
+			raise NotImplementedError(orientation)
+
 	def _is_history_visible(self, model, iter):
 		try:
 			action = model.get_value(iter, self.ACTION_IDX)
@@ -1404,6 +1428,14 @@ class MessagesView(object):
 		config.set(sectionName, "status", self._messageStatus)
 		config.set(sectionName, "type", self._messageType)
 
+	def set_orientation(self, orientation):
+		if orientation == gtk.ORIENTATION_VERTICAL:
+			pass
+		elif orientation == gtk.ORIENTATION_HORIZONTAL:
+			pass
+		else:
+			raise NotImplementedError(orientation)
+
 	def _is_message_visible(self, model, iter):
 		try:
 			message = model.get_value(iter, self.MESSAGE_DATA_IDX)
@@ -1701,6 +1733,14 @@ class ContactsView(object):
 	def save_settings(self, config, sectionName):
 		config.set(sectionName, "selectedAddressbook", str(self._selectedComboIndex))
 
+	def set_orientation(self, orientation):
+		if orientation == gtk.ORIENTATION_VERTICAL:
+			pass
+		elif orientation == gtk.ORIENTATION_HORIZONTAL:
+			pass
+		else:
+			raise NotImplementedError(orientation)
+
 	def _idly_populate_contactsview(self):
 		with gtk_toolbox.gtk_lock():
 			banner = hildonize.show_busy_banner_start(self._window, "Loading Contacts")
